package com.inspect.patrol.mapper;

import com.inspect.patrol.domain.PatrolLinkagePos;
import com.inspect.patrol.domain.PatrolPoint;
import com.inspect.patrol.linkage.block.IBlock;
import com.inspect.patrol.linkage.frame.LinkageSignEntity;
import com.inspect.patrol.model.LinkageActionConfig;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface PatrolLinkagePosMapper {
    PatrolLinkagePos selectPatrolLinkagePosByLinkagePosId(Long posId);

    List<PatrolPoint> selectPatrolPointList(String key);

    List<PatrolLinkagePos> selectPatrolLinkagePosByIds(List<Long> ids);

    List<PatrolLinkagePos> selectPatrolLinkagePosList(PatrolLinkagePos pos);

    PatrolLinkagePos selectPatrolLinkagePos(LinkageSignEntity linkageSignEntity);

    int insertPatrolLinkagePos(List<IBlock> blockList);

    int updatePatrolLinkagePos(List<IBlock> blockList);

    int updateLinkageActionConfig(LinkageActionConfig config);

    int deletePatrolLinkagePosByLinkagePosId(Long posId);

    int deletePatrolLinkagePosByLinkagePosIds(Long[] posIds);
}
